@@ -30,14 +30,28 @@ class Drone(Base):
     discriminator = Column('type', String(50))
     __mapper_args__ = {'polymorphic_on': discriminator}
 
-    id = Column(String, primary_key=True)
+    id = Column(Integer, primary_key=True, autoincrement=True)
     name = Column(String, default='')
     ip_address = Column(String, default='')
     zmq_public_key = Column(String)
     zmq_private_key = Column(String)
-    configuration = Column(String)
     last_activity = Column(DateTime, default=datetime.datetime.min)
 
+    # for display purposes
+    def to_dict(self):
+        if self.last_activity == datetime.datetime.min:
+            timestamp = 'Never'
+        else:
+            timestamp = self.last_activity.strftime('%Y-%m-%d %H:%M:%S')
+        if self.discriminator is None:
+            _type = 'None'
+        else:
+            _type = self.discriminator.capitalize()
+
+        result = {'id': self.id, 'name': self.name, 'type': _type, 'last_activity': timestamp, 'ip': self.ip_address}
+
+        return result
+
 
 # edge between honeypot and client
 class DroneEdge(Base):
